@@ -2,8 +2,8 @@
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile 
-  (require 'irchat-inlines))
+(eval-when-compile
+  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
 
 ;;;
 ;;;  000 replies -- what is the author of ircd thinking
