@@ -3,7 +3,8 @@
 ;;; see file irchat-copyright.el for change log and copyright info
 
 (eval-when-compile
-  (require 'irchat-inlines))
+  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
+
 ;;;
 ;;;  400 replies -- ERRORS
 ;;; 
