@@ -4,8 +4,7 @@
 ;;; see file irchat-copyright.el for change log and copyright info
 
 (eval-when-compile 
-  (require 'irchat-inlines)
-  (require 'irchat-globals)
+  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
   (require 'irchat-dcc)
   (require 'gnus-caesar))
 
@@ -542,7 +541,9 @@ be a string to send NICK upon entering."
 (defun irchat-Command-away (awaymsg)
   "Mark/unmark yourself as being away."
   (interactive "sAway message: ")
-  (irchat-send "AWAY :%s" awaymsg))
+  (progn
+    (irchat-send "AWAY :%s" awaymsg)
+    (setq irchat-awaymsg awaymsg)))
 
 
 (defun irchat-Command-scroll-down ()
