@@ -8,7 +8,7 @@
 ;;; All Rights Reserved
 
 (eval-when-compile
-  (require 'irchat-inlines))
+  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
 
 (defvar irchat-dcc-receive-list nil)
 (defvar irchat-dcc-receive-direct t)
