@@ -3,10 +3,6 @@
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (if (not (featurep 'irchat-inlines))
-      (require 'irchat-inlines)))
-(provide 'irchat-globals)
 
 ;;;
 ;;; Do not change these
@@ -15,10 +11,10 @@
 (defconst irchat-client-version-major "2"
   "Major version number. Major functional changes change this number.")
 
-(defconst irchat-client-version-minor "52"
+(defconst irchat-client-version-minor "53"
   "Minor version number. Server Protocol changes and bug fixes change this number.")
 
-(defconst irchat-client-version-release "$Date: 1995/03/25 22:22:22 $"
+(defconst irchat-client-version-release "$Date: 1995/09/20 01:30:07 $"
   "version release date")
 
 (defconst irchat-client-name "Irchat"
@@ -125,6 +121,10 @@ a greeting telling what version of IRCHAT this is.")
 (defvar irchat-userathost ""
   "The user@host for the current line.")
 
+(defvar irchat-awaymsg ""
+  "Current away message.")
+
+
 (defvar irchat-debug-buffer nil)
 (defvar irchat-server-buffer nil)
 (defvar irchat-server-name nil)
@@ -186,6 +186,7 @@ make-vector for more information. Here is a list of some small primes...
 (defconst irchat-query-client-ping
   (concat "PING" irchat-query-client-insert-to-generic))
 
+(provide 'irchat-globals)
 ;;;
 ;;;  eof
 ;;; 
