@@ -3,12 +3,11 @@
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'defsubst)
-  (provide 'irchat-inlines)
-  (load "irchat-globals")
-  (require 'irchat-vars))
-
+;;; these must be loaded in the file that requires this since this
+;;; won't work otherwise.
+;;;(eval-when-compile
+;;;  (require 'irchat-globals)
+;;;  (require 'irchat-vars))
 
 (defsubst irchat-scan-channels (chnl)
   (setq irchat-channel-alist 
@@ -141,6 +140,8 @@
   (save-excursion 
     (irchat-w-insert irchat-D-buffer (format "%s\n" msg))))
 
+(provide 'irchat-inlines)
+
 ;;;
 ;;;  eof
 ;;;
