@@ -4,9 +4,8 @@
 ;;; see file irchat-copyright.el for change log and copyright info
 
 (eval-when-compile
-  (require 'irchat-inlines)
-  (require 'irchat-filter)
-  (require 'irchat-vars))
+  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
+  (require 'irchat-filter))
 
 (provide 'irchat)
 
@@ -339,6 +338,7 @@ If already connected, just pop up the windows."
 	      (setq irchat-freeze-indicator "-")
 	      (irchat-freeze-toggle (car irchat-D-buffer))))
 	(irchat-Dialogue-setup-buffer)
+	(irchat-Private-setup-buffer)
 	(irchat-KILLS-setup-buffer)
 	(irchat-IGNORED-setup-buffer)
 	(irchat-WALLOPS-setup-buffer)
@@ -348,6 +348,8 @@ If already connected, just pop up the windows."
 	    (irchat-Command-join irchat-current-channel)
 	  (if irchat-startup-channel
 	      (irchat-Command-join irchat-startup-channel)))
+	(if (not (string-equal irchat-awaymsg ""))
+	    (irchat-Command-away irchat-awaymsg))
 	(run-hooks 'irchat-Startup-hook)
 	(setq 
 	 irchat-obarray (make-vector irchat-obarray-size nil)
@@ -481,6 +483,12 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	(set-buffer (get-buffer-create irchat-Dialogue-buffer))
 	(irchat-Dialogue-mode))))
 
+(defun irchat-Private-setup-buffer ()
+  "Initialize Dialogue mode buffer for private messages."
+  (or (get-buffer irchat-Private-buffer)
+      (save-excursion
+	(set-buffer (get-buffer-create irchat-Private-buffer))
+	(irchat-Dialogue-mode))))
 
 (defun irchat-KILLS-setup-buffer ()
   "Initialize KILLS buffer."
