@@ -24,8 +24,8 @@
 	  (if interval
 	      (start-itimer "IRCHAT" function interval interval))))
     (progn
-      (eval-when-compile
-	(require 'timer))
+;;      (eval-when-compile
+;;	(require 'timer))
       (defun irchat-cancel-timer (timer)
 	"Cancel timer."
 	(cancel-timer timer))
