@@ -3,8 +3,6 @@
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(provide 'irchat-vars)
-
 ;;;
 ;;; user modifiable variables
 ;;;
@@ -96,6 +94,9 @@ killed again if automagic reconnect is too fast.")
 (defvar irchat-format-string ">%s<"
   "*Format string for private messages being sent.")
 
+(defvar irchat-format-string0 "-%s-"
+  "*Format string for arriving NOTICE messages.")
+
 (defvar irchat-format-string1 "=%s="
   "*Format string for arriving private messages.")
 
@@ -132,7 +133,9 @@ IRCHAT to suit old users of the irc-loser-client.")
 (defvar irchat-Dialogue-buffer "*IRC Dialogue*"
   "*Name of Dialogue output buffer")
 
-(defvar irchat-Privmsg-buffer nil)
+(defvar irchat-Private-buffer "*IRC Private*")
+
+;;;(defvar irchat-Privmsg-buffer nil)
 (defvar irchat-KILLS-buffer "*IRC KILLS*")
 (defvar irchat-IGNORED-buffer "*IRC IGNORED*")
 (defvar irchat-WALLOPS-buffer "*IRC WALLOPS*")
@@ -271,7 +274,7 @@ The last ignores all messages that contain the word `fuck`.
 
 (defvar irchat-D-buffer (list irchat-Dialogue-buffer)
   "*A list of buffer where normal Dialogue is sent.")
-(defvar irchat-P-buffer (list irchat-Dialogue-buffer "*IRC Private*")
+(defvar irchat-P-buffer (list irchat-Dialogue-buffer irchat-Private-buffer)
   "*A list of buffers where private messages to me are sent.")
 (defvar irchat-I-buffer (list irchat-IGNORED-buffer)
   "*A list of buffers where private messages to me are sent.")
@@ -340,6 +343,7 @@ would cause messages from and to channel #report to be displayed on
 buffer named *report-buffer* and all other messages are displayed on
 Dialogue-buffer.")
 
+(provide 'irchat-vars)
 ;;;
 ;;; eof
 ;;;
